@@ -112,8 +112,10 @@ def swt(data, wavelet, level=None, start_level=0, axis=-1,
 
     if not _have_c99_complex and np.iscomplexobj(data):
         data = np.asarray(data)
-        coeffs_real = swt(data.real, wavelet, level, start_level, trim_approx)
-        coeffs_imag = swt(data.imag, wavelet, level, start_level, trim_approx)
+        kwargs = dict(wavelet=wavelet, level=level, start_level=start_level,
+                      trim_approx=trim_approx, axis=axis, norm=norm)
+        coeffs_real = swt(data.real, **kwargs)
+        coeffs_imag = swt(data.imag, **kwargs)
         if not trim_approx:
             coeffs_cplx = []
             for (cA_r, cD_r), (cA_i, cD_i) in zip(coeffs_real, coeffs_imag):
@@ -138,7 +140,7 @@ def swt(data, wavelet, level=None, start_level=0, axis=-1,
     if axis < 0:
         axis = axis + data.ndim
     if not 0 <= axis < data.ndim:
-        raise ValueError("Axis greater than data dimensions")
+        raise np.AxisError("Axis greater than data dimensions")
 
     if level is None:
         level = swt_max_level(data.shape[axis])
@@ -150,7 +152,7 @@ def swt(data, wavelet, level=None, start_level=0, axis=-1,
     return ret
 
 
-def iswt(coeffs, wavelet, norm=False):
+def iswt(coeffs, wavelet, norm=False, axis=-1):
     """
     Multilevel 1D inverse discrete stationary wavelet transform.
 
@@ -182,27 +184,37 @@ def iswt(coeffs, wavelet, norm=False):
     array([ 1.,  2.,  3.,  4.,  5.,  6.,  7.,  8.])
     """
     # copy to avoid modification of input data
-
     # If swt was called with trim_approx=False, first element is a tuple
     trim_approx = not isinstance(coeffs[0], (tuple, list))
-
-    if trim_approx:
-        cA = coeffs[0]
-        coeffs = coeffs[1:]
-    else:
-        cA = coeffs[0][0]
-
-    dt = _check_dtype(cA)
-    output = np.array(cA, dtype=dt, copy=True)
-    if not _have_c99_complex and np.iscomplexobj(output):
-        # compute real and imaginary separately then combine
+    cA = coeffs[0] if trim_approx else coeffs[0][0]
+    if cA.ndim > 1:
+        # convert to swtn coefficient format and call iswtn
+        if trim_approx:
+            coeffs_nd = [cA] + [{'d': d} for d in coeffs[1:]]
+        else:
+            coeffs_nd = [{'a': a, 'd': d} for a, d in coeffs]
+        return iswtn(coeffs_nd, wavelet, axes=(axis,), norm=norm)
+    elif axis != 0 and axis != -1:
+        raise np.AxisError("Axis greater than data dimensions")
+    if not _have_c99_complex and np.iscomplexobj(cA):
         if trim_approx:
             coeffs_real = [c.real for c in coeffs]
             coeffs_imag = [c.imag for c in coeffs]
         else:
-            coeffs_real = [(cA.real, cD.real) for (cA, cD) in coeffs]
-            coeffs_imag = [(cA.imag, cD.imag) for (cA, cD) in coeffs]
-        return iswt(coeffs_real, wavelet) + 1j*iswt(coeffs_imag, wavelet)
+            coeffs_real = [(ca.real, cd.real) for ca, cd in coeffs]
+            coeffs_imag = [(ca.imag, cd.imag) for ca, cd in coeffs]
+        kwargs = dict(wavelet=wavelet, norm=norm)
+        y = iswt(coeffs_real, **kwargs)
+        return y + 1j * iswt(coeffs_imag, **kwargs)
+
+    if trim_approx:
+        coeffs = coeffs[1:]
+
+    if cA.ndim != 1:
+        raise ValueError("iswt only supports 1D data")
+
+    dt = _check_dtype(cA)
+    output = np.array(cA, dtype=dt, copy=True)
 
     # num_levels, equivalent to the decomposition level, n
     num_levels = len(coeffs)
@@ -286,7 +298,7 @@ def swt2(data, wavelet, level, start_level=0, axes=(-2, -1),
     -------
     coeffs : list
         Approximation and details coefficients (for ``start_level = m``).
-        If ``trim_approx`` is ``True``, approximation coefficients are
+        If ``trim_approx`` is ``False``, approximation coefficients are
         retained for all levels::
 
             [
@@ -305,7 +317,7 @@ def swt2(data, wavelet, level, start_level=0, axes=(-2, -1),
         where cA is approximation, cH is horizontal details, cV is
         vertical details, cD is diagonal details and m is ``start_level``.
 
-        If ``trim_approx`` is ``False``, approximation coefficients are only
+        If ``trim_approx`` is ``True``, approximation coefficients are only
         retained at the final level of decomposition. This matches the format
         used by ``pywt.wavedec2``::
 
@@ -365,7 +377,7 @@ def swt2(data, wavelet, level, start_level=0, axes=(-2, -1),
     return ret
 
 
-def iswt2(coeffs, wavelet, norm=False):
+def iswt2(coeffs, wavelet, norm=False, axes=(-2, -1)):
     """
     Multilevel 2D inverse discrete stationary wavelet transform.
 
@@ -418,11 +430,33 @@ def iswt2(coeffs, wavelet, norm=False):
 
     # If swt was called with trim_approx=False, first element is a tuple
     trim_approx = not isinstance(coeffs[0], (tuple, list))
+    cA = coeffs[0] if trim_approx else coeffs[0][0]
+    if cA.ndim != 2 or axes != (-2, -1):
+        # convert to swtn coefficient format and call iswtn instead
+        if trim_approx:
+            coeffs_nd = [cA] + [{'da': h, 'ad': v, 'dd': d}
+                                for h, v, d in coeffs[1:]]
+        else:
+            coeffs_nd = [{'aa': a, 'da': h, 'ad': v, 'dd': d}
+                         for a, (h, v, d) in coeffs]
+        return iswtn(coeffs_nd, wavelet, axes=axes, norm=norm)
+    if not _have_c99_complex and np.iscomplexobj(cA):
+        if trim_approx:
+            coeffs_real = [cA.real]
+            coeffs_real += [(h.real, v.real, d.real) for h, v, d in coeffs[1:]]
+            coeffs_imag = [cA.imag]
+            coeffs_imag += [(h.imag, v.imag, d.imag) for h, v, d in coeffs[1:]]
+        else:
+            coeffs_real = [(a.real, (h.real, v.real, d.real))
+                            for a, (h, v, d) in coeffs]
+            coeffs_imag = [(a.imag, (h.imag, v.imag, d.imag))
+                            for a, (h, v, d) in coeffs]
+        kwargs = dict(wavelet=wavelet, norm=norm)
+        y = iswt2(coeffs_real, **kwargs)
+        return y + 1j * iswt2(coeffs_imag, **kwargs)
+
     if trim_approx:
-        cA = coeffs[0]
         coeffs = coeffs[1:]
-    else:
-        cA = coeffs[0][0]
 
     # copy to avoid modification of input data
     dt = _check_dtype(cA)
@@ -580,8 +614,10 @@ def swtn(data, wavelet, level, start_level=0, axes=None, trim_approx=False,
     """
     data = np.asarray(data)
     if not _have_c99_complex and np.iscomplexobj(data):
-        real = swtn(data.real, wavelet, level, start_level, axes, trim_approx)
-        imag = swtn(data.imag, wavelet, level, start_level, axes, trim_approx)
+        kwargs = dict(wavelet=wavelet, level=level, start_level=start_level,
+                      trim_approx=trim_approx, axes=axes, norm=norm)
+        real = swtn(data.real, **kwargs)
+        imag = swtn(data.imag, **kwargs)
         if trim_approx:
             cplx = [real[0] + 1j * imag[0]]
             offset = 1
@@ -601,6 +637,8 @@ def swtn(data, wavelet, level, start_level=0, axes=None, trim_approx=False,
     if axes is None:
         axes = range(data.ndim)
     axes = [a + data.ndim if a < 0 else a for a in axes]
+    if any(a < 0 or a >= data.ndim for a in axes):
+        raise np.AxisError("Axis greater than data dimensions")
     if len(axes) != len(set(axes)):
         raise ValueError("The axes passed to swtn must be unique.")
     num_axes = len(axes)
@@ -678,13 +716,25 @@ def iswtn(coeffs, wavelet, axes=None, norm=False):
 
     # key length matches the number of axes transformed
     ndim_transform = max(len(key) for key in coeffs[-1].keys())
-
     trim_approx = not isinstance(coeffs[0], dict)
+    cA = coeffs[0] if trim_approx else coeffs[0]['a'*ndim_transform]
+
+    if not _have_c99_complex and np.iscomplexobj(cA):
+        if trim_approx:
+            coeffs_real = [coeffs[0].real]
+            coeffs_imag = [coeffs[0].imag]
+            coeffs = coeffs[1:]
+        else:
+            coeffs_real = []
+            coeffs_imag = []
+        coeffs_real += [{k: v.real for k, v in c.items()} for c in coeffs]
+        coeffs_imag += [{k: v.imag for k, v in c.items()} for c in coeffs]
+        kwargs = dict(wavelet=wavelet, axes=axes, norm=norm)
+        y = iswtn(coeffs_real, **kwargs)
+        return y + 1j * iswtn(coeffs_imag, **kwargs)
+
     if trim_approx:
-        cA = coeffs[0]
         coeffs = coeffs[1:]
-    else:
-        cA = coeffs[0]['a'*ndim_transform]
 
     # copy to avoid modification of input data
     dt = _check_dtype(cA)
